==> MoarSigns-1.10.2-4.2.3.10-sources.jar: gory_moon/moarsigns/client/interfaces/GuiHandler.java <==
package gory_moon.moarsigns.client.interfaces;

import gory_moon.moarsigns.client.interfaces.containers.ContainerDebug;
import gory_moon.moarsigns.client.interfaces.containers.ContainerExchange;
import gory_moon.moarsigns.client.interfaces.containers.ContainerPreview;
import gory_moon.moarsigns.client.interfaces.containers.InventoryExchange;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.IInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.text.ITextComponent;
import net.minecraft.world.World;
import net.minecraftforge.fml.common.network.IGuiHandler;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

public class GuiHandler implements IGuiHandler {

    public static final int DEBUG_TILE = 0;
    public static final int DEBUG_ITEM = 1;
    public static final int EXCHANGE = 2;
    public static final int PREVIEW = 3;
    private IInventory tempInv;

    public GuiHandler() {
        tempInv = new IInventory() {

            @Override
            public ITextComponent func_145748_c_() {
                return null;
            }

            ItemStack stack;

            @Override
            public int func_70302_i_() {
                return 1;
            }

            @Override
            public ItemStack func_70301_a(int i) {
                return stack;
            }

            @Override
            public ItemStack func_70298_a(int i, int j) {
                ItemStack itemstack = func_70301_a(i);

                if (itemstack != null) {
                    if (itemstack.field_77994_a <= j) {
                        func_70299_a(i, null);
                    } else {
                        itemstack = itemstack.func_77979_a(j);
                        func_70296_d();
                    }
                }

                return itemstack;
            }

            @Override
            public ItemStack func_70304_b(int i) {
                ItemStack item = func_70301_a(i);

                func_70299_a(i, null);

                return item;
            }

            @Override
            public void func_70299_a(int i, ItemStack itemstack) {
                stack = itemstack;

                if (itemstack != null && itemstack.field_77994_a > func_70297_j_()) {
                    itemstack.field_77994_a = func_70297_j_();
                }

                func_70296_d();
            }

            @Override
            public String func_70005_c_() {
                return "DummyInventory";
            }

            @Override
            public boolean func_145818_k_() {
                return false;
            }

            @Override
            public int func_70297_j_() {
                return 1;
            }

            @Override
            public void func_70296_d() {
                // Dummy method
            }

            @Override
            public boolean func_70300_a(EntityPlayer entityplayer) {
                return true;
            }

            @Override
            public void func_174889_b(EntityPlayer player) {

            }

            @Override
            public void func_174886_c(EntityPlayer player) {

            }

            @Override
            public boolean func_94041_b(int i, ItemStack itemstack) {
                return true;
            }

            @Override
            public int func_174887_a_(int id) {
                return 0;
            }

            @Override
            public void func_174885_b(int id, int value) {
                // Dummy method
            }

            @Override
            public int func_174890_g() {
                return 0;
            }

            @Override
            public void func_174888_l() {
                // Dummy method
            }
        };
    }

    @Override
    public Object getServerGuiElement(int ID, EntityPlayer player, World world, int x, int y, int z) {

        switch (ID) {
            case DEBUG_TILE:
            case DEBUG_ITEM:
                return new ContainerDebug(player.field_71071_by, ID, tempInv);
            case EXCHANGE:
                return new ContainerExchange(player.field_71071_by, new InventoryExchange());
            case PREVIEW:
                return new ContainerPreview();
        }

        return null;
    }

    @Override
    @SideOnly(Side.CLIENT)
    public Object getClientGuiElement(int ID, EntityPlayer player, World world, int x, int y, int z) {

        BlockPos pos = new BlockPos(x, y, z);

        switch (ID) {
            case DEBUG_TILE:
            case DEBUG_ITEM:
                return new GuiDebug(player.field_71071_by, ID, world, pos, tempInv);
            case EXCHANGE:
                return new GuiExchange(player.field_71071_by, new InventoryExchange());
            case PREVIEW:
                return new GuiPreview();
        }

        return null;
    }
}

==> MoarSigns-1.12.2-6.0.0.11-sources.jar: gory_moon/moarsigns/client/interfaces/GuiHandler.java <==
package gory_moon.moarsigns.client.interfaces;

import gory_moon.moarsigns.client.interfaces.containers.ContainerDebug;
import gory_moon.moarsigns.client.interfaces.containers.ContainerExchange;
import gory_moon.moarsigns.client.interfaces.containers.ContainerPreview;
import gory_moon.moarsigns.client.interfaces.containers.InventoryExchange;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.IInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumHand;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.text.ITextComponent;
import net.minecraft.world.World;
import net.minecraftforge.fml.common.network.IGuiHandler;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

public class GuiHandler implements IGuiHandler {

    public static final int DEBUG_TILE = 0;
    public static final int DEBUG_ITEM = 1;
    public static final int EXCHANGE = 2;
    public static final int PREVIEW = 3;
    private IInventory tempInv;

    public GuiHandler() {
        tempInv = new IInventory() {

            @Override
            public ITextComponent func_145748_c_() {
                return null;
            }

            private ItemStack stack = ItemStack.field_190927_a;

            @Override
            public int func_70302_i_() {
                return 1;
            }

            @Override
            public boolean func_191420_l() {
                return false;
            }

            @Override
            public ItemStack func_70301_a(int i) {
                return stack;
            }

            @Override
            public ItemStack func_70298_a(int i, int j) {
                ItemStack itemstack = func_70301_a(i);

                if (!itemstack.func_190926_b()) {
                    if (itemstack.func_190916_E() <= j) {
                        func_70299_a(i, ItemStack.field_190927_a);
                    } else {
                        itemstack = itemstack.func_77979_a(j);
                        func_70296_d();
                    }
                }

                return itemstack;
            }

            @Override
            public ItemStack func_70304_b(int i) {
                ItemStack item = func_70301_a(i);

                func_70299_a(i, ItemStack.field_190927_a);

                return item;
            }

            @Override
            public void func_70299_a(int i, ItemStack itemstack) {
                stack = itemstack;

                if (!itemstack.func_190926_b() && itemstack.func_190916_E() > func_70297_j_()) {
                    itemstack.func_190920_e(func_70297_j_());
                }

                func_70296_d();
            }

            @Override
            public String func_70005_c_() {
                return "DummyInventory";
            }

            @Override
            public boolean func_145818_k_() {
                return false;
            }

            @Override
            public int func_70297_j_() {
                return 1;
            }

            @Override
            public void func_70296_d() {
                // Dummy method
            }

            @Override
            public boolean func_70300_a(EntityPlayer player) {
                return true;
            }

            @Override
            public void func_174889_b(EntityPlayer player) {

            }

            @Override
            public void func_174886_c(EntityPlayer player) {

            }

            @Override
            public boolean func_94041_b(int i, ItemStack itemstack) {
                return true;
            }

            @Override
            public int func_174887_a_(int id) {
                return 0;
            }

            @Override
            public void func_174885_b(int id, int value) {
                // Dummy method
            }

            @Override
            public int func_174890_g() {
                return 0;
            }

            @Override
            public void func_174888_l() {
                // Dummy method
            }
        };
    }

    @Override
    public Object getServerGuiElement(int ID, EntityPlayer player, World world, int x, int y, int z) {

        EnumHand hand = EnumHand.values()[x];
        switch (ID) {
            case DEBUG_TILE:
            case DEBUG_ITEM:
                return new ContainerDebug(player.field_71071_by, ID, tempInv);
            case EXCHANGE:
                return new ContainerExchange(player.field_71071_by, new InventoryExchange(), hand);
            case PREVIEW:
                return new ContainerPreview();
        }

        return null;
    }

    @Override
    @SideOnly(Side.CLIENT)
    public Object getClientGuiElement(int ID, EntityPlayer player, World world, int x, int y, int z) {

        BlockPos pos = new BlockPos(x, y, z);
        EnumHand hand = EnumHand.values()[x];
        switch (ID) {
            case DEBUG_TILE:
            case DEBUG_ITEM:
                return new GuiDebug(player.field_71071_by, ID, world, pos, tempInv);
            case EXCHANGE:
                return new GuiExchange(player.field_71071_by, new InventoryExchange(), hand);
            case PREVIEW:
                return new GuiPreview();
        }

        return null;
    }
}
